@@ -13,12 +13,13 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Lyceum person specific code.
 """
+from zope.catalog.text import TextIndex
+from zope.index.text.interfaces import ISearchableText
 from zope.interface import implements
 from zope.component import adapts
 
@@ -113,9 +114,27 @@ class BasicPersonCalendarCrowd(PersonCalendarCrowd):
 
 class PersonCatalog(AttributeCatalog):
 
-    version = '1 - replaced catalog utility'
+    version = '2 - added text index'
     interface = IBasicPerson
     attributes = ('__name__', 'title', 'first_name', 'last_name')
 
+    def setIndexes(self, catalog):
+        super(PersonCatalog, self).setIndexes(catalog)
+        catalog['text'] = TextIndex('getSearchableText', ISearchableText, True)
+
 
 getPersonCatalog = PersonCatalog.get
+
+
+class SearchableTextPerson(object):
+
+    adapts(IBasicPerson)
+    implements(ISearchableText)
+
+    def __init__(self, context):
+        self.context = context
+
+    def getSearchableText(self):
+        result = [self.context.first_name, self.context.last_name,
+                  self.context.username]
+        return ' '.join(result)
