@@ -42,6 +42,7 @@ from zope.i18n import translate
 from z3c.form import form, subform, field, button
 from z3c.form.interfaces import DISPLAY_MODE
 
+from schooltool.app.browser.app import ActiveSchoolYearContentMixin
 from schooltool.app.interfaces import ISchoolToolApplication
 from schooltool.app.catalog import buildQueryString
 from schooltool.contact.interfaces import IContactable
@@ -844,17 +845,12 @@ class PersonAsContactLinkViewlet(flourish.page.LinkIdViewlet):
                                                          person.last_name)})
 
 
-class FlourishManageContactsOverview(flourish.page.Content):
+class FlourishManageContactsOverview(flourish.page.Content,
+                                     ActiveSchoolYearContentMixin):
 
     body_template = ViewPageTemplateFile(
         'templates/f_manage_contacts_overview.pt')
 
-    @property
-    def has_schoolyear(self):
-        schoolyears = ISchoolYearContainer(self.context)
-        schoolyear = schoolyears.getActiveSchoolYear()
-        return schoolyear is not None
-
     @property
     def contacts(self):
         app = ISchoolToolApplication(None)
@@ -866,6 +862,9 @@ class FlourishManageContactsOverview(flourish.page.Content):
         catalog = ICatalog(self.contacts)
         return len(catalog.extent)
 
+    def contacts_url(self):
+        return self.url_with_schoolyear_id(self.context, view_name='contacts')
+
 
 class ContactActionsLinks(flourish.page.RefineLinksViewlet):
     """Contact actions links viewlet."""
