@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Report browser views.
@@ -647,3 +646,7 @@ class ReportArchivePage(ProgressReportPage):
 class RequestReportArchiveDialog(RequestRemoteReportDialog):
 
     task_factory = ArchiveReportTask
+
+
+class ReportReferenceLinkViewlet(flourish.page.LinkViewlet):
+    pass
