@@ -13,8 +13,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
 """
 Base classes for report reference and request adapters
@@ -404,6 +403,8 @@ class AbstractReportTask(RemoteTask):
         from zope.security.checker import ProxyFactory
         principal = Principal(self.creator.__name__, 'XXX:title',
                               person=ProxyFactory(self.creator))
+        for group in self.creator.groups:
+            principal.groups.append("sb.group." + group.__name__)
         request.principal = principal
         zope.security.management.endInteraction()
         zope.security.management.newInteraction(request)
